==> haskell-one-liner-2.1-256.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-Ab6SAbiXc5jLC7R9l50Xve
key:                  one-liner-2.1-Ab6SAbiXc5jLC7R9l50Xve
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  fe9393500ac73d284161e8f4eb876957
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-Ab6SAbiXc5jLC7R9l50Xve
depends:
    base-4.18.2.1 bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW ghc-prim-0.10.0
    linear-base-0.5.0-Ato5x4FpKWB6UodtdPty9K
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-one-liner-2.1-257-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-JGoz44uByia3s2DqHA7ZcS
key:                  one-liner-2.1-JGoz44uByia3s2DqHA7ZcS
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  12eeffdaebb4ff02f038a607fae1319c
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-JGoz44uByia3s2DqHA7ZcS
depends:
    base-4.18.2.1 bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW ghc-prim-0.10.0
    linear-base-0.5.0-1MNjLdrc3Rb4ZCtZGlgwja
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
